@@ -3,7 +3,7 @@
 
 #include "base/factory.h"
 
-#include <kdemacros.h>
+#include "lib/libksirtet_export.h"
 
 struct CommonBoardInfo {
     uint baseTime, dropDownTime, beforeGlueTime, afterGlueTime;
@@ -17,7 +17,7 @@ class AI;
 
 #define cfactory static_cast<CommonFactory *>(BaseFactory::self())
 
-class KDE_EXPORT CommonFactory : public BaseFactory
+class LIBKSIRTET_EXPORT CommonFactory : public BaseFactory
 {
  public:
     CommonFactory(const MainData &, const BaseBoardInfo &,
